// Generated by CoffeeScript 1.6.3
var app, args, bits, compile, compiler, compilers, conf, confs, credentials, cwd, err, error, exec, ext, fs, k, log, mod, opt, opts, os, server, usage, v, websocket, _i, _j, _len, _len1, _ref, _ref1, _ref2, _ref3, _ref4;

exec = require('executive');

fs = require('fs');

os = require('os');

compilers = require('./compilers');

server = require('./server');

log = require('./utils').log;

error = function(message) {
  console.error(message);
  return process.exit(1);
};

usage = function() {
  console.log("bebop [options]\n\nOptions:\n  --compilers, -c Specify compiler to use for a given extension\n  --force-compile Compile files and exit\n  --host, -h      Hostname to bind to\n  --no-compile    Do not compile files automatically\n  --no-watch      Do not watch files for changes\n  --no-server     Do not run static file server\n  --open, -o      Open browser automatically\n  --port, -p      Port to listen on\n  --secure, -s    Require authentication");
  return process.exit(0);
};

require.extensions['.coffee'] = function() {
  require('coffee-script');
  return require.extensions['.coffee'].apply(require.extensions, arguments);
};

cwd = process.cwd();

confs = [process.env.HOME + '/.bebop', cwd + '/.bebop'];

opts = {
  compile: true,
  host: 'localhost',
  port: 1987,
  watch: true,
  compilers: {},
  runServer: true
};

for (_i = 0, _len = confs.length; _i < _len; _i++) {
  conf = confs[_i];
  try {
    conf = require.resolve(conf);
  } catch (_error) {
    err = _error;
    continue;
  }
  if (fs.existsSync(conf)) {
    _ref = require(conf);
    for (k in _ref) {
      v = _ref[k];
      opts[k] = v;
    }
  }
}

args = process.argv.slice(2);

while (opt = args.shift()) {
  switch (opt) {
    case '--help':
    case '-v':
      usage();
      break;
    case '--open':
    case '-o':
      opts.open = true;
      break;
    case '--no-server':
      opts.runServer = false;
      break;
    case '--no-watch':
      opts.watch = false;
      break;
    case '--no-compile':
      opts.compile = false;
      break;
    case '--force-compile':
      opts.forceCompile = true;
      break;
    case '--host':
    case '-h':
      opts.host = args.shift();
      break;
    case '--port':
    case '-p':
      opts.port = parseInt(args.shift(), 10);
      break;
    case '--secure':
    case '-s':
      credentials = args.shift();
      if (credentials) {
        _ref1 = credentials.split(':'), opts.user = _ref1[0], opts.pass = _ref1[1];
      } else {
        opts.user = 'bebop';
        opts.pass = 'beepboop';
      }
      break;
    case '--compilers':
    case '-c':
      _ref2 = args.shift().split(',');
      for (_j = 0, _len1 = _ref2.length; _j < _len1; _j++) {
        compiler = _ref2[_j];
        _ref3 = compiler.split(':'), ext = _ref3[0], mod = _ref3[1];
        opts.compilers[ext] = mod;
      }
      break;
    default:
      if (opt.charAt(0) === '-') {
        error('Unrecognized option');
      }
  }
}

_ref4 = opts.compilers;
for (ext in _ref4) {
  compiler = _ref4[ext];
  if (typeof compiler === 'string') {
    try {
      bits = compiler.split('.');
      compiler = require(bits.shift());
      while (bits.length) {
        compiler = compiler[bits.shift()];
      }
      compilers[ext] = compiler;
    } catch (_error) {
      err = _error;
      console.log(err);
    }
  } else {
    compilers[ext] = compiler;
  }
}

compile = function(filename, cb) {
  if (cb == null) {
    cb = function() {};
  }
  return compilers.compile(filename, function(err, compiled) {
    if (filename.indexOf(cwd === 0)) {
      filename = (filename.replace(cwd, '')).replace(/^\//, '');
    }
    if (err != null) {
      log.error('error', "failed to compile " + filename);
      console.error(err.stderr != null ? err.stderr : err.stack);
      return;
    }
    if (compiled) {
      log.info('compiled', filename);
    }
    return cb(null, compiled);
  });
};

(require('vigil')).walk(cwd, function(filename) {
  if (opts.compile) {
    return compile(filename);
  }
});

if (opts.runServer) {
  app = server.createServer(opts);
  websocket = (require('./websocket'))({
    server: app
  });
} else {
  app = {
    run: function() {}
  };
  websocket = {
    modified: function() {}
  };
}

if (!opts.forceCompile) {
  if (opts.watch) {
    (require('vigil')).watch(cwd, function(filename, stat, isModule) {
      if (!opts.compile) {
        log.info('modified', filename);
        return websocket.modified(filename);
      }
      return compile(filename, function(err, compiled) {
        if (!compiled) {
          log.info('modified', filename);
          return websocket.modified(filename);
        }
      });
    });
  }
  app.run();
  if (opts.open) {
    switch (os.platform()) {
      case 'darwin':
        exec("open http://" + opts.host + ":" + opts.port);
        break;
      case 'linux':
        exec("xdg-open http://" + opts.host + ":" + opts.port);
    }
  }
}

/*
//@ sourceMappingURL=cli.map
*/
